@@ -3,6 +3,7 @@ from deezer.pagination import PaginatedList
 from deezer.resources import (
     Album,
     Artist,
+    Editorial,
     Genre,
     Playlist,
     Radio,
@@ -11,13 +12,14 @@ from deezer.resources import (
     User,
 )
 
-__version__ = "5.0.1"
+__version__ = "5.2.0"
 __all__ = [
     "Client",
     "PaginatedList",
     "Resource",
     "Album",
     "Artist",
+    "Editorial",
     "Genre",
     "Playlist",
     "Track",
