@@ -283,14 +283,13 @@ class Client:
         """
         return self.request("GET", f"genre/{genre_id}")
 
-    def list_genres(self) -> PaginatedList[Genre]:
+    def list_genres(self) -> list[Genre]:
         """
         List musical genres.
 
-        :returns: a :class:`~deezer.pagination.PaginatedList`
-                  of :class:`~deezer.resources.Genre` objects.
+        :return: a list of :class:`~deezer.resources.Genre` instances
         """
-        return self._get_paginated_list("genre")
+        return self.request("GET", "genre")
 
     def get_playlist(self, playlist_id: int) -> Playlist:
         """
@@ -316,14 +315,13 @@ class Client:
         """
         return self.request("GET", f"radio/{radio_id}")
 
-    def list_radios(self) -> PaginatedList[Radio]:
+    def list_radios(self) -> list[Radio]:
         """
         List radios.
 
-        :returns: a :class:`~deezer.pagination.PaginatedList`
-                  of :class:`~deezer.resources.Radio` objects.
+        :return: a list of :class:`~deezer.resources.Radio` instances
         """
-        return self._get_paginated_list("radio")
+        return self.request("GET", "radio")
 
     def get_radios_top(self) -> PaginatedList[Radio]:
         """
@@ -351,7 +349,7 @@ class Client:
         user_id_str = str(user_id) if user_id else "me"
         return self.request("GET", f"user/{user_id_str}")
 
-    def get_user_albums(self, user_id: int | None = None) -> PaginatedList:
+    def get_user_albums(self, user_id: int | None = None) -> PaginatedList[Album]:
         """
         Get the favourites albums for the given user_id if provided or current user if not.
 
